# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .column_type_item_number_default_value import ColumnTypeItemNumberDefaultValue
from .column_type_item_number_min_value import ColumnTypeItemNumberMinValue
from .column_type_item_number_max_value import ColumnTypeItemNumberMaxValue
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ColumnTypeItemNumber(UncheckedBaseModel):
    column_id: typing.Optional[str] = None
    column_display_name: typing.Optional[str] = None
    column_type: typing.Literal["number"] = "number"
    default_value: typing.Optional[ColumnTypeItemNumberDefaultValue] = None
    min_value: typing.Optional[ColumnTypeItemNumberMinValue] = None
    max_value: typing.Optional[ColumnTypeItemNumberMaxValue] = None
    data_type: typing.Optional[typing.Literal["number"]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from .document import Document

EvalServiceHandlersCreateDocumentResponseData = typing.Union[Document, typing.List[Document]]
